@@ -8,8 +8,6 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
 
-from os.path import basename
-
 SITENAME = AUTHOR = "Hypothesis"
 SITESUBTITLE = "The property-based testing library for Python"
 # SITEURL = "https://hypothesis.works"
@@ -40,12 +38,16 @@ FILENAME_METADATA = r"(?P<date>\d{4}-\d{2}-\d{2})-(?P<slug>.+)"
 
 THEME = "./theme/"
 STATIC_PATHS = [
+    "images",
     "../../brand/favicon.ico",
     "../../brand/dragonfly-rainbow.svg",
     "../archive-redirect.html",
 ]
-EXTRA_PATH_METADATA = {k: {"path": basename(k)} for k in STATIC_PATHS}
-EXTRA_PATH_METADATA["../archive-redirect.html"] = {"path": "archives.html"}
+EXTRA_PATH_METADATA = {
+    "../../brand/favicon.ico": {"path": "favicon.ico"},
+    "../../brand/dragonfly-rainbow.svg": {"path": "dragonfly-rainbow.svg"},
+    "../archive-redirect.html": {"path": "archives.html"},
+}
 PROFILE_IMAGE_URL = "/dragonfly-rainbow.svg"
 
 MENUITEMS = (
@@ -55,6 +57,34 @@ MENUITEMS = (
     ("PyPI", "https://pypi.org/project/hypothesis/"),
 )
 
+# Author information - map from short alias to full name and URL
+AUTHOR_NAMES = {
+    "alexwlchan": "Alex Chan",
+    "carlini": "Nicholas Carlini",
+    "drmaciver": "David R. MacIver",
+    "giorgiosironi": "Giorgio Sironi",
+    "hwayne": "Hillel Wayne",
+    "jml": "Jonathan M. Lange",
+    "liam": "Liam DeVoe",
+    "maaz": "Muhammad Maaz",
+    "nchammas": "Nicholas Chammas",
+    "zac-hd": "Zac Hatfield-Dodds",
+}
+
+AUTHOR_URLS = {
+    "alexwlchan": "https://alexwlchan.net",
+    "carlini": "https://nicholas.carlini.com/",
+    "drmaciver": "http://www.drmaciver.com",
+    "giorgiosironi": "http://giorgiosironi.com",
+    "hwayne": "https://www.hillelwayne.com/",
+    "jml": "https://jml.io",
+    "liam": "https://tybug.dev",
+    "maaz": "https://www.mmaaz.ca/",
+    "nchammas": "http://nchammas.com",
+    "zac-hd": "https://zhd.dev",
+}
+assert set(AUTHOR_URLS).issubset(AUTHOR_NAMES)
+
 DEFAULT_PAGINATION = False
 
 # same as the default from https://docs.getpelican.com/en/latest/settings.html#MARKDOWN,
